@@ -233,42 +233,62 @@ public class CSVFormatTest {
                 if (name.startsWith("with")) {
                     for (final Class<?> cls : method.getParameterTypes()) {
                         final String type = cls.getCanonicalName();
-                        if ("boolean".equals(type)) {
+                        switch (type) {
+                        case "boolean": {
                             final Object defTrue = method.invoke(CSVFormat.DEFAULT, Boolean.TRUE);
                             final Object defFalse = method.invoke(CSVFormat.DEFAULT, Boolean.FALSE);
                             assertNotEquals(name, type, defTrue, defFalse);
-                        } else if ("char".equals(type)) {
+                            break;
+                        }
+                        case "char": {
                             final Object a = method.invoke(CSVFormat.DEFAULT, 'a');
                             final Object b = method.invoke(CSVFormat.DEFAULT, 'b');
                             assertNotEquals(name, type, a, b);
-                        } else if ("java.lang.Character".equals(type)) {
+                            break;
+                        }
+                        case "java.lang.Character": {
                             final Object a = method.invoke(CSVFormat.DEFAULT, new Object[] { null });
                             final Object b = method.invoke(CSVFormat.DEFAULT, Character.valueOf('d'));
                             assertNotEquals(name, type, a, b);
-                        } else if ("java.lang.String".equals(type)) {
+                            break;
+                        }
+                        case "java.lang.String": {
                             final Object a = method.invoke(CSVFormat.DEFAULT, new Object[] { null });
                             final Object b = method.invoke(CSVFormat.DEFAULT, "e");
                             assertNotEquals(name, type, a, b);
-                        } else if ("java.lang.String[]".equals(type)) {
+                            break;
+                        }
+                        case "java.lang.String[]": {
                             final Object a = method.invoke(CSVFormat.DEFAULT, new Object[] { new String[] { null, null } });
                             final Object b = method.invoke(CSVFormat.DEFAULT, new Object[] { new String[] { "f", "g" } });
                             assertNotEquals(name, type, a, b);
-                        } else if ("org.apache.commons.csv.QuoteMode".equals(type)) {
+                            break;
+                        }
+                        case "org.apache.commons.csv.QuoteMode": {
                             final Object a = method.invoke(CSVFormat.DEFAULT, QuoteMode.MINIMAL);
                             final Object b = method.invoke(CSVFormat.DEFAULT, QuoteMode.ALL);
                             assertNotEquals(name, type, a, b);
-                        } else if ("org.apache.commons.csv.DuplicateHeaderMode".equals(type)) {
+                            break;
+                        }
+                        case "org.apache.commons.csv.DuplicateHeaderMode": {
                             final Object a = method.invoke(CSVFormat.DEFAULT, DuplicateHeaderMode.ALLOW_ALL);
                             final Object b = method.invoke(CSVFormat.DEFAULT, DuplicateHeaderMode.DISALLOW);
                             assertNotEquals(name, type, a, b);
-                        } else if ("java.lang.Object[]".equals(type)) {
+                            break;
+                        }
+                        case "java.lang.Object[]": {
                             final Object a = method.invoke(CSVFormat.DEFAULT, new Object[] { new Object[] { null, null } });
                             final Object b = method.invoke(CSVFormat.DEFAULT, new Object[] { new Object[] { new Object(), new Object() } });
                             assertNotEquals(name, type, a, b);
-                        } else if ("withHeader".equals(name)) { // covered above by String[]
-                            // ignored
-                        } else {
-                            fail("Unhandled method: " + name + "(" + type + ")");
+                            break;
+                        }
+                        default:
+                            if ("withHeader".equals(name)) { // covered above by String[]
+                                // ignored
+                            } else {
+                                fail("Unhandled method: " + name + "(" + type + ")");
+                            }
+                            break;
                         }
                     }
                 }
@@ -695,11 +715,21 @@ public class CSVFormatTest {
 
     @Test
     public void testFormatToString() {
-        final CSVFormat format = CSVFormat.RFC4180.withEscape('?').withDelimiter(',').withQuoteMode(QuoteMode.MINIMAL).withRecordSeparator(CRLF).withQuote('"')
-                .withNullString("").withIgnoreHeaderCase(true).withHeaderComments("This is HeaderComments").withHeader("col1", "col2", "col3");
+        // @formatter:off
+        final CSVFormat format = CSVFormat.RFC4180
+                .withEscape('?')
+                .withDelimiter(',')
+                .withQuoteMode(QuoteMode.MINIMAL)
+                .withRecordSeparator(CRLF)
+                .withQuote('"')
+                .withNullString("")
+                .withIgnoreHeaderCase(true)
+                .withHeaderComments("This is HeaderComments")
+                .withHeader("col1", "col2", "col3");
+        // @formatter:on
         assertEquals(
-                "Delimiter=<,> Escape=<?> QuoteChar=<\"> QuoteMode=<MINIMAL> NullString=<> RecordSeparator=<" + CRLF
-                        + "> IgnoreHeaderCase:ignored SkipHeaderRecord:false HeaderComments:[This is HeaderComments] Header:[col1, col2, col3]",
+                "Delimiter=<,> Escape=<?> QuoteChar=<\"> QuoteMode=<MINIMAL> NullString=<> RecordSeparator=<" + CRLF +
+                        "> IgnoreHeaderCase:ignored SkipHeaderRecord:false HeaderComments:[This is HeaderComments] Header:[col1, col2, col3]",
                 format.toString());
     }
 
@@ -940,12 +970,14 @@ public class CSVFormatTest {
 
     @Test
     public void testQuoteModeNoneShouldReturnMeaningfulExceptionMessage() {
-        final Exception exception = assertThrows(IllegalArgumentException.class, () -> {
+        final Exception exception = assertThrows(IllegalArgumentException.class, () ->
+        // @formatter:off
             CSVFormat.DEFAULT.builder()
                     .setHeader("Col1", "Col2", "Col3", "Col4")
                     .setQuoteMode(QuoteMode.NONE)
-                    .build();
-        });
+                    .build()
+        // @formatter:on
+        );
         final String actualMessage = exception.getMessage();
         final String expectedMessage = "Quote mode set to NONE but no escape character is set";
         assertEquals(expectedMessage, actualMessage);
